@@ -4,7 +4,7 @@ import os
 import sys
 import tempfile
 
-__version__ = '0.1.7'
+__version__ = '0.1.8'
 
 
 PY2 = sys.version_info[0] == 2
@@ -117,9 +117,7 @@ class AtomicWriter(object):
         try:
             with get_fileobject() as f:
                 yield f
-                f.flush()
-                os.fsync(f.fileno())
-
+                self.sync(f)
             self.commit(f)
         except:
             try:
@@ -135,6 +133,12 @@ class AtomicWriter(object):
         return tempfile.NamedTemporaryFile(mode=self._mode, dir=dir,
                                            delete=False, **kwargs)
 
+    def sync(self, f):
+        '''responsible for clearing as many file caches as possible before
+        commit'''
+        f.flush()
+        os.fsync(f.fileno())
+
     def commit(self, f):
         '''Move the temporary file to the target location.'''
         if self._overwrite:
